==> esp8266-0.3.0.crate: esp8266-0.3.0/src/wdt/reset_stage.rs <==
#[doc = "Register `reset_stage` reader"]
pub struct R(crate::R<RESET_STAGE_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<RESET_STAGE_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::convert::From<crate::R<RESET_STAGE_SPEC>> for R {
    fn from(reader: crate::R<RESET_STAGE_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `reset_stage` writer"]
pub struct W(crate::W<RESET_STAGE_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<RESET_STAGE_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl core::convert::From<crate::W<RESET_STAGE_SPEC>> for W {
    fn from(writer: crate::W<RESET_STAGE_SPEC>) -> Self {
        W(writer)
    }
}
impl R {}
impl W {
    #[doc = "Writes raw bits to the register."]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Watchdog stage reset\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [reset_stage](index.html) module"]
pub struct RESET_STAGE_SPEC;
impl crate::RegisterSpec for RESET_STAGE_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [reset_stage::R](R) reader structure"]
impl crate::Readable for RESET_STAGE_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [reset_stage::W](W) writer structure"]
impl crate::Writable for RESET_STAGE_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets reset_stage to value 0"]
impl crate::Resettable for RESET_STAGE_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}

==> esp8266-0.4.0.crate: esp8266-0.4.0/src/wdt/reset_stage.rs <==
#[doc = "Register `reset_stage` reader"]
pub struct R(crate::R<RESET_STAGE_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<RESET_STAGE_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<RESET_STAGE_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<RESET_STAGE_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `reset_stage` writer"]
pub struct W(crate::W<RESET_STAGE_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<RESET_STAGE_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<RESET_STAGE_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<RESET_STAGE_SPEC>) -> Self {
        W(writer)
    }
}
impl W {
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "Watchdog stage reset\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [reset_stage](index.html) module"]
pub struct RESET_STAGE_SPEC;
impl crate::RegisterSpec for RESET_STAGE_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [reset_stage::R](R) reader structure"]
impl crate::Readable for RESET_STAGE_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [reset_stage::W](W) writer structure"]
impl crate::Writable for RESET_STAGE_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets reset_stage to value 0"]
impl crate::Resettable for RESET_STAGE_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0
    }
}
